@@ -1,24 +1,25 @@
 export { LineAttributesEditor as default };
+
+var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };
+
+function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }
+
 import React, { Component } from 'react';
 import PropTypes from 'prop-types';
 import { FormNumberInput, FormTextInput } from '../../../style/export';
 import { PropertyLengthMeasure } from '../../../../catalog/properties/export';
 
-var tableStyle = {
-  width: '100%'
-};
-var firstTdStyle = {
-  width: '6em'
-};
-var inputStyle = {
-  textAlign: 'left'
-};
+var tableStyle = { width: '100%' };
+var firstTdStyle = { width: '6em' };
+var inputStyle = { textAlign: 'left' };
 
 function LineAttributesEditor(_ref, _ref2) {
   var element = _ref.element,
       _onUpdate = _ref.onUpdate,
       attributeFormData = _ref.attributeFormData,
-      state = _ref.state;
+      state = _ref.state,
+      rest = _objectWithoutProperties(_ref, ['element', 'onUpdate', 'attributeFormData', 'state']);
+
   var translator = _ref2.translator;
 
 
@@ -47,9 +48,13 @@ function LineAttributesEditor(_ref, _ref2) {
           React.createElement(
             'td',
             null,
-            React.createElement(FormTextInput, { value: name, onChange: function onChange(event) {
+            React.createElement(FormTextInput, {
+              value: name,
+              onChange: function onChange(event) {
                 return _onUpdate('name', event.target.value);
-              }, style: inputStyle })
+              },
+              style: inputStyle
+            })
           )
         ),
         React.createElement(
@@ -63,13 +68,15 @@ function LineAttributesEditor(_ref, _ref2) {
           React.createElement(
             'td',
             null,
-            React.createElement(FormNumberInput, {
+            React.createElement(FormNumberInput, _extends({
               value: vertexOne.get('x'),
               onChange: function onChange(event) {
                 return _onUpdate('vertexOne', { 'x': event.target.value });
-              }, style: inputStyle,
-              state: state
-            })
+              },
+              style: inputStyle,
+              state: state,
+              configs: { precision: 2 }
+            }, rest))
           )
         ),
         React.createElement(
@@ -83,13 +90,15 @@ function LineAttributesEditor(_ref, _ref2) {
           React.createElement(
             'td',
             null,
-            React.createElement(FormNumberInput, {
+            React.createElement(FormNumberInput, _extends({
               value: vertexOne.get('y'),
               onChange: function onChange(event) {
                 return _onUpdate('vertexOne', { 'y': event.target.value });
-              }, style: inputStyle,
-              state: state
-            })
+              },
+              style: inputStyle,
+              state: state,
+              configs: { precision: 2 }
+            }, rest))
           )
         ),
         React.createElement(
@@ -103,13 +112,15 @@ function LineAttributesEditor(_ref, _ref2) {
           React.createElement(
             'td',
             null,
-            React.createElement(FormNumberInput, {
+            React.createElement(FormNumberInput, _extends({
               value: vertexTwo.get('x'),
               onChange: function onChange(event) {
                 return _onUpdate('vertexTwo', { 'x': event.target.value });
-              }, style: inputStyle,
-              state: state
-            })
+              },
+              style: inputStyle,
+              state: state,
+              configs: { precision: 2 }
+            }, rest))
           )
         ),
         React.createElement(
@@ -123,13 +134,15 @@ function LineAttributesEditor(_ref, _ref2) {
           React.createElement(
             'td',
             null,
-            React.createElement(FormNumberInput, {
+            React.createElement(FormNumberInput, _extends({
               value: vertexTwo.get('y'),
               onChange: function onChange(event) {
                 return _onUpdate('vertexTwo', { 'y': event.target.value });
-              }, style: inputStyle,
-              state: state
-            })
+              },
+              style: inputStyle,
+              state: state,
+              configs: { precision: 2 }
+            }, rest))
           )
         )
       )
@@ -139,7 +152,7 @@ function LineAttributesEditor(_ref, _ref2) {
       onUpdate: function onUpdate(mapped) {
         return _onUpdate('lineLength', mapped);
       },
-      configs: { label: translator.t('Length'), min: 0, max: Infinity },
+      configs: { label: translator.t('Length'), min: 0, max: Infinity, precision: 2 },
       state: state
     })
   );
@@ -148,6 +161,7 @@ function LineAttributesEditor(_ref, _ref2) {
 LineAttributesEditor.propTypes = {
   element: PropTypes.object.isRequired,
   onUpdate: PropTypes.func.isRequired,
+  onValid: PropTypes.func,
   attributeFormData: PropTypes.object.isRequired,
   state: PropTypes.object.isRequired
 };
