@@ -567,7 +567,7 @@ function updateBoundingBox(planData) {
  * @returns {Array}
  */
 function filterDiffs(diffArray, sceneData, oldSceneData) {
-  return minimizeRemoveDiffsWhenSwitchingLayers(minimizeChangePropertiesDiffs(diffArray, sceneData, oldSceneData), sceneData, oldSceneData);
+  return minimizeRemoveDiffsWhenSwitchingLayers(minimizeChangePropertiesAfterSelectionsDiffs(minimizeChangePropertiesDiffs(diffArray, sceneData, oldSceneData), sceneData, oldSceneData), sceneData, oldSceneData);
 }
 
 /**
@@ -599,6 +599,31 @@ function minimizeRemoveDiffsWhenSwitchingLayers(diffArray, sceneData, oldSceneDa
   return diffArray;
 }
 
+/**
+ * Reduces the number of change properties diffs for selected elements
+ * @param diffArray the array of the diffs
+ * @param sceneData
+ * @param oldSceneData
+ * @returns {Array}
+ */
+function minimizeChangePropertiesAfterSelectionsDiffs(diffArray, sceneData, oldSceneData) {
+  var idsFound = {};
+  diffArray.forEach(function (diff) {
+    var split = diff.path.split('/');
+    if (split[5] === 'selected') {
+      idsFound[split[4]] = split[4];
+    }
+  });
+
+  return diffArray.filter(function (diff) {
+    var split = diff.path.split('/');
+    if (split[5] === 'properties') {
+      return idsFound[split[4]] ? false : true;
+    }
+    return true;
+  });
+}
+
 /**
  * Reduces the number of change properties diffs
  * @param diffArray the array of the diffs
@@ -611,7 +636,7 @@ function minimizeChangePropertiesDiffs(diffArray, sceneData, oldSceneData) {
   return diffArray.filter(function (diff) {
     var split = diff.path.split('/');
     if (split[5] === 'properties') {
-      return idsFound[split[4]] ? false : idsFound[split[4]] = 1;
+      return idsFound[split[4]] ? false : idsFound[split[4]] = true;
     } else if (split[5] === "misc") {
       // Remove misc changes
       return false;
