@@ -291,7 +291,7 @@ OBJLoader.prototype = {
         var ia = this.parseVertexIndex(a, vLen);
         var ib = this.parseVertexIndex(b, vLen);
         var ic = this.parseVertexIndex(c, vLen);
-        var id;
+        var id = void 0;
 
         if (d === undefined) {
 
@@ -358,7 +358,7 @@ OBJLoader.prototype = {
           this.addVertexLine(this.parseVertexIndex(vertices[vi], vLen));
         }
 
-        for (var uvi = 0, l = uvs.length; uvi < l; uvi++) {
+        for (var uvi = 0, _l = uvs.length; uvi < _l; uvi++) {
 
           this.addUVLine(this.parseUVIndex(uvs[uvi], uvLen));
         }
@@ -539,9 +539,9 @@ OBJLoader.prototype = {
     var container = new THREE.Group();
     container.materialLibraries = [].concat(state.materialLibraries);
 
-    for (var i = 0, l = state.objects.length; i < l; i++) {
+    for (var _i = 0, _l2 = state.objects.length; _i < _l2; _i++) {
 
-      var object = state.objects[i];
+      var object = state.objects[_i];
       var geometry = object.geometry;
       var materials = object.materials;
       var isLine = geometry.type === 'Line';
@@ -573,42 +573,42 @@ OBJLoader.prototype = {
       for (var mi = 0, miLen = materials.length; mi < miLen; mi++) {
 
         var sourceMaterial = materials[mi];
-        var material = undefined;
+        var _material = undefined;
 
         if (this.materials !== null) {
 
-          material = this.materials.create(sourceMaterial.name);
+          _material = this.materials.create(sourceMaterial.name);
 
           // mtl etc. loaders probably can't create line materials correctly, copy properties to a line material.
-          if (isLine && material && !(material instanceof THREE.LineBasicMaterial)) {
+          if (isLine && _material && !(_material instanceof THREE.LineBasicMaterial)) {
 
             var materialLine = new THREE.LineBasicMaterial();
-            materialLine.copy(material);
-            material = materialLine;
+            materialLine.copy(_material);
+            _material = materialLine;
           }
         }
 
-        if (!material) {
+        if (!_material) {
 
-          material = !isLine ? new THREE.MeshPhongMaterial() : new THREE.LineBasicMaterial();
-          material.name = sourceMaterial.name;
+          _material = !isLine ? new THREE.MeshPhongMaterial() : new THREE.LineBasicMaterial();
+          _material.name = sourceMaterial.name;
         }
 
-        if (!sourceMaterial.smooth) material.flatShading = true;
+        if (!sourceMaterial.smooth) _material.flatShading = true;
 
-        createdMaterials.push(material);
+        createdMaterials.push(_material);
       }
 
       // Create mesh
 
-      var mesh;
+      var mesh = void 0;
 
       if (createdMaterials.length > 1) {
 
-        for (var mi = 0, miLen = materials.length; mi < miLen; mi++) {
+        for (var _mi = 0, _miLen = materials.length; _mi < _miLen; _mi++) {
 
-          var sourceMaterial = materials[mi];
-          buffergeometry.addGroup(sourceMaterial.groupStart, sourceMaterial.groupCount, mi);
+          var _sourceMaterial = materials[_mi];
+          buffergeometry.addGroup(_sourceMaterial.groupStart, _sourceMaterial.groupCount, _mi);
         }
 
         var multiMaterial = new THREE.MultiMaterial(createdMaterials);
