@@ -3,13 +3,15 @@ import Content from './content';
 import SidebarComponents from './sidebar/export';
 import FooterBarComponents from './footerbar/export';
 import Viewer2DComponents from './viewer2d/export';
+import StyleComponents from './style/export';
 
 export {
   ToolbarComponents,
   Content,
   SidebarComponents,
   FooterBarComponents,
-  Viewer2DComponents
+  Viewer2DComponents,
+  StyleComponents
 };
 
 export default {
@@ -17,5 +19,6 @@ export default {
   Content,
   SidebarComponents,
   FooterBarComponents,
-  Viewer2DComponents
+  Viewer2DComponents,
+  StyleComponents
 };
