@@ -372,9 +372,11 @@ function addHole(sceneData, planData, layer, holeID, catalog, holesActions) {
       return holesActions.selectHole(layer.id, holeData.id)
     });
 
-    if (!holeData.selected) {
-      applyOpacity(pivot, layer.opacity);
+    let opacity = layer.opacity;
+    if (holeData.selected) {
+      opacity = 1;
     }
+    applyOpacity(pivot, opacity);
 
   });
 }
@@ -412,9 +414,11 @@ function addLine(sceneData, planData, layer, lineID, catalog, linesActions) {
       return linesActions.selectLine(layer.id, line.id);
     });
 
-    if (!line.selected && layer.opacity !== 1) {
-      applyOpacity(pivot, layer.opacity);
+    let opacity = layer.opacity;
+    if (line.selected) {
+      opacity = 1;
     }
+    applyOpacity(pivot, opacity);
 
   });
 }
@@ -439,14 +443,18 @@ function addArea(sceneData, planData, layer, areaID, catalog, areaActions) {
 
     applyInteract(pivot, interactFunction);
 
-    if (!area.selected && layer.opacity !== 1) {
-      applyOpacity(pivot, layer.opacity);
+    let opacity = layer.opacity;
+    if (area.selected) {
+      opacity = 1;
     }
 
+    applyOpacity(pivot, opacity);
+
   });
 }
 
 function addItem(sceneData, planData, layer, itemID, catalog, itemsActions) {
+
   let item = layer.items.get(itemID);
 
   return catalog.getElement(item.type).render3D(item, layer, sceneData).then(item3D => {
@@ -468,10 +476,13 @@ function addItem(sceneData, planData, layer, itemID, catalog, itemsActions) {
       }
     );
 
-    if (!item.selected && layer.opacity !== 1) {
-      applyOpacity(pivot, layer.opacity);
+    let opacity = layer.opacity;
+    if (item.selected) {
+      opacity = 1;
     }
 
+    applyOpacity(pivot, opacity);
+
     planData.plan.add(pivot);
     planData.sceneGraph.layers[layer.id].items[item.id] = pivot;
   });
@@ -490,6 +501,7 @@ function applyInteract(object, interactFunction) {
 // Apply opacity to children of an Object3D
 function applyOpacity(object, opacity) {
   object.traverse(function (child) {
+
     if (child instanceof Three.Mesh) {
       if (child.material instanceof Three.MultiMaterial) {
         child.material.materials.forEach(materialChild => {
@@ -501,6 +513,16 @@ function applyOpacity(object, opacity) {
             materialChild.opacity = opacity;
           }
         });
+      } else if (child.material instanceof Array) {
+        child.material.forEach(material => {
+          material.transparent = true;
+          if (material.maxOpacity) {
+            material.opacity = Math.min(material.maxOpacity, opacity);
+          } else if (material.opacity && material.opacity > opacity) {
+            material.maxOpacity = material.opacity;
+            material.opacity = opacity;
+          }
+        });
       } else {
         child.material.transparent = true;
         if (child.material.maxOpacity) {
@@ -549,7 +571,9 @@ function updateBoundingBox(planData) {
  */
 function filterDiffs(diffArray, sceneData, oldSceneData) {
   return minimizeRemoveDiffsWhenSwitchingLayers(
-    minimizeChangePropertiesDiffs(diffArray, sceneData, oldSceneData), sceneData, oldSceneData);
+    minimizeChangePropertiesAfterSelectionsDiffs(
+      minimizeChangePropertiesDiffs(diffArray, sceneData, oldSceneData), sceneData, oldSceneData),
+    sceneData, oldSceneData);
 }
 
 /**
@@ -583,6 +607,31 @@ function minimizeRemoveDiffsWhenSwitchingLayers(diffArray, sceneData, oldSceneDa
   return diffArray;
 }
 
+/**
+ * Reduces the number of change properties diffs for selected elements
+ * @param diffArray the array of the diffs
+ * @param sceneData
+ * @param oldSceneData
+ * @returns {Array}
+ */
+function minimizeChangePropertiesAfterSelectionsDiffs(diffArray, sceneData, oldSceneData) {
+  let idsFound = {};
+  diffArray.forEach(diff => {
+    let split = diff.path.split('/');
+    if (split[5] === 'selected') {
+      idsFound[split[4]] = split[4];
+    }
+  });
+
+  return diffArray.filter(diff => {
+    let split = diff.path.split('/');
+    if (split[5] === 'properties') {
+      return idsFound[split[4]] ? false : true;
+    }
+    return true;
+  });
+}
+
 /**
  * Reduces the number of change properties diffs
  * @param diffArray the array of the diffs
@@ -595,7 +644,7 @@ function minimizeChangePropertiesDiffs(diffArray, sceneData, oldSceneData) {
   return diffArray.filter(diff => {
     let split = diff.path.split('/');
     if (split[5] === 'properties') {
-      return idsFound[split[4]] ? false : ( idsFound[split[4]] = 1 );
+      return idsFound[split[4]] ? false : (idsFound[split[4]] = true);
     } else if (split[5] === "misc") {
       // Remove misc changes
       return false;
