@@ -64,19 +64,20 @@ export function splitLine(layer, lineID, x, y, catalog) {
 
   layer = layer.withMutations(layer => {
     let line = layer.getIn(['lines', lineID]);
-    let {x: x0, y: y0} = layer.vertices.get(line.vertices.get(0));
-    let {x: x1, y: y1} = layer.vertices.get(line.vertices.get(1));
+    let v0 = layer.vertices.get(line.vertices.get(0));
+    let v1 = layer.vertices.get(line.vertices.get(1));
+    let {x: x0, y: y0} = v0;
+    let {x: x1, y: y1} = v1;
 
     ({line: line0} = addLine(layer, line.type, x0, y0, x, y, catalog, line.properties));
     ({line: line1} = addLine(layer, line.type, x1, y1, x, y, catalog, line.properties));
 
     let splitPointOffset = Geometry.pointPositionOnLineSegment(x0, y0, x1, y1, x, y);
+    let minVertex = Geometry.minVertex(v0, v1);
 
     line.holes.forEach(holeID => {
       let hole = layer.holes.get(holeID);
 
-      let minVertex = Geometry.minVertex({x: x0, y: y0}, {x: x1, y: y1});
-
       let holeOffset = hole.offset;
       if (minVertex.x === x1 && minVertex.y === y1) {
         splitPointOffset = 1 - splitPointOffset;
@@ -155,15 +156,14 @@ export function addLineAvoidingIntersections(layer, type, x0, y0, x1, y1, catalo
       let [v0, v1] = line.vertices.map(vertexID => vertices.get(vertexID)).toArray();
 
       let hasCommonEndpoint =
-        (Geometry.samePoints(v0, {x: x0, y: y0})
-          || Geometry.samePoints(v0, {x: x1, y: y1})
-          || Geometry.samePoints(v1, {x: x0, y: y0})
-          || Geometry.samePoints(v1, {x: x1, y: y1}));
+        (Geometry.samePoints(v0, points[0])
+          || Geometry.samePoints(v0, points[1])
+          || Geometry.samePoints(v1, points[0])
+          || Geometry.samePoints(v1, points[1]));
 
 
       let intersection = Geometry.intersectionFromTwoLineSegment(
-        {x: x0, y: y0}, {x: x1, y: y1},
-        v0, v1
+        points[0], points[1], v0, v1
       );
 
       if (intersection.type === 'colinear') {
@@ -171,7 +171,7 @@ export function addLineAvoidingIntersections(layer, type, x0, y0, x1, y1, catalo
           oldHoles = [];
         }
 
-        let orderedVertices = Geometry.orderVertices([{x: x0, y: y0}, {x: x1, y: y1}]);
+        let orderedVertices = Geometry.orderVertices(points);
 
         layer.lines.get(line.id).holes.forEach(holeID => {
           let hole = layer.holes.get(holeID);
@@ -536,7 +536,9 @@ export function detectAndUpdateAreas(layer, catalog) {
 
     // Build a relationship between areas and their coordinates
     let verticesCoordsForArea = areaIDs.map(id => {
-      let vertices = layer.areas.get(id).vertices.map(vertexID => layer.vertices.get(vertexID));
+      let vertices = layer.areas.get(id).vertices.map(vertexID => {
+        let { x, y } = layer.vertices.get(vertexID); return new List([x,y]);
+      });
       return { id, vertices };
     });
 
